@@ -19,3 +19,8 @@ hr_area.RasterLayer <- function(x, level = 0.95, ...) {
     x <- cumulative_ud(x)
     sum(x[] <= level) * prod(raster::res(x))
 }
+
+#' @export
+hr_area.kde <- function(x, level = 0.95, ...) {
+  hr_area(x$ud, level = level, ...)
+}
